#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IS_NOT_NAN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IS_NOT_NAN_HPP_INCLUDED

#include <boost/simd/predicates/include/functions/is_not_nan.hpp>

#endif
